@@ -1,4 +1,4 @@
 rgl.sphtext <-
-function(long,lat,radius,text,deg=FALSE,col='black',...){
+function(long,lat,radius,text,deg=TRUE,col='black',...){
 text3d(sph2car(long,lat,radius,deg=deg),texts=text,col=col,...)
 }
